/*---------------------------------------------------------------------------
 * File Name: t3pl_concurrency.h
 *
 * Copyright 2001-2004 Telelogic AB, All rights reserved.
 *
 * This Program is owned by Telelogic and is protected by national
 * copyright laws and international copyright treaties. Telelogic
 * grants you the right to use this Program on one computer or in one
 * local computer network at any one time.  Under this License you may
 * only modify the source code for the purpose of adapting it to your
 * environment. You must reproduce and include any copyright and
 * trademark notices on all copies of the source code.  You may not
 * use, copy, merge, modify or transfer the Program except as provided
 * in this License.  Telelogic does not warrant that the Program will
 * meet your requirements or that the operation of the Program will be
 * uninterrupted and error free. You are solely responsible that the
 * selection of the Program and the modification of the source code
 * will achieve your intended results and that the results are
 * actually obtained.
 */


#ifndef __t3pl_concurrency_h
#define __t3pl_concurrency_h

#ifdef __cplusplus
extern "C" {
#endif

#include "t3rts.h"


/*
 * This function returns globally unique Id number for current task
 * This may be process id or thread id or etc.
 * Note: this function does not receive context through parameters
 */

unsigned long
t3pl_task_id();

void
t3pl_concurrency_pre_initialize (int argc, char * argv [], t3rt_context_t ctx);

void
t3pl_concurrency_initialize (t3rt_context_t ctx);

void
t3pl_concurrency_finalize (t3rt_context_t ctx);


/*
 * Start the first (non-CPC) component of the current process.
 * This function is supposed to end by calling the t3rt_component_main
 * function with the newly created control port address of this
 * component along with the provided context.
 */

void
t3pl_concurrency_start_separate_component(int argc, const char* argv[],
                                          t3rt_context_t ctx);



void
t3pl_task_register_context (t3rt_context_t context);


/* 
 * Create a port to control the task and a thread of execution executing 
 * the 't3rt_component_main' function. 
 * 
 * The binary string 'address' is set to the address of the control port 
 * of the new task.
 */

void
t3pl_task_create(int argc,
                 const char * argv[],
                 t3rt_value_t component_value,
                 t3rt_binary_string_t address,
                 t3rt_context_t context);


/*
 *  This function is called from the t3rt_component_main function in an 
 *  attempt to setup whatever is necessary for the component to 
 *  communicate through its ports.
 *  It is created after the control port has been created but before any
 *  other port is created and before any communication between components 
 *  is made.
 */

void
t3pl_task_setup(t3rt_binary_string_t compaddr, t3rt_context_t context);


/*
 * Force task to stop executing. If the component did shutdown according 
 * to normal shutdown procedures the 'shutdown_acknowledged' flag wil be 
 * true.
 */

void
t3pl_task_kill (t3rt_binary_string_t address, 
                const t3rt_boolean_t shutdown_acknowledged,
                t3rt_context_t context);


/*
 * Called to terminate this task
 */

void
t3pl_task_exit (t3rt_context_cleanup_function_t context_cleanup_f,
                t3rt_context_t context);





void *
t3pl_sem_create (unsigned int value, t3rt_context_t ctx);

t3rt_boolean_t 
t3pl_sem_wait (void *sem, t3rt_context_t ctx);

t3rt_boolean_t 
t3pl_sem_trywait (void *sem, t3rt_context_t ctx);

t3rt_boolean_t 
t3pl_sem_timedwait(void * sem, double wait_seconds, t3rt_context_t ctx);

t3rt_boolean_t 
t3pl_sem_post (void *sem, t3rt_context_t ctx);     

t3rt_boolean_t 
t3pl_sem_destroy (void *sem, t3rt_context_t ctx);

#ifdef __cplusplus
}
#endif

#endif

/* End of File */

