/*---------------------------------------------------------------------------
 * File Name: t3pl_memory.h
 *
 * Copyright 2001-2004 Telelogic AB, All rights reserved.
 * 
 * This Program is owned by Telelogic and is protected by national
 * copyright laws and international copyright treaties. Telelogic
 * grants you the right to use this Program on one computer or in one
 * local computer network at any one time.  Under this License you may
 * only modify the source code for the purpose of adapting it to your
 * environment. You must reproduce and include any copyright and
 * trademark notices on all copies of the source code.  You may not
 * use, copy, merge, modify or transfer the Program except as provided
 * in this License.  Telelogic does not warrant that the Program will
 * meet your requirements or that the operation of the Program will be
 * uninterrupted and error free. You are solely responsible that the
 * selection of the Program and the modification of the source code
 * will achieve your intended results and that the results are
 * actually obtained.
 */


#ifndef __t3pl_memory_h
#define __t3pl_memory_h

#ifdef __cplusplus
extern "C" {
#endif

#include "t3rts.h"


/*
 * After a call to this function, the 't3rt_memory_allocate' function must be working.
 */

void
t3pl_memory_pre_initialize (int argc, char * argv []);


/*
 * After a call to this function, all memory primitives must be available.
 */

void
t3pl_memory_initialize (t3rt_context_t ctx);


/*
 * Finalizes memory module.
 */

void
t3pl_memory_finalize (t3rt_context_t ctx);


/*
 * Allocate 'size' number of bytes
 */

void *
t3pl_memory_allocate (const t3rt_alloc_strategy_t strategy,
                      const unsigned long size, 
                      t3rt_context_t context);


/*
 * Deallocate the given memory block
 */

void
t3pl_memory_deallocate (const t3rt_alloc_strategy_t strategy,
                        void *mem, 
                        t3rt_context_t context); 


/*
 * Reallocate the given memory block
 */

void *
t3pl_memory_reallocate (const t3rt_alloc_strategy_t strategy,
                        void *mem, 
                        const unsigned long new_size, 
                        t3rt_context_t context);


#ifdef __cplusplus
}
#endif

#endif

/* End of File */

