/*---------------------------------------------------------------------------
 * File Name: t3pl_time.h
 *
 * Copyright 2001-2004 Telelogic AB, All rights reserved.
 *
 * This Program is owned by Telelogic and is protected by national
 * copyright laws and international copyright treaties. Telelogic
 * grants you the right to use this Program on one computer or in one
 * local computer network at any one time.  Under this License you may
 * only modify the source code for the purpose of adapting it to your
 * environment. You must reproduce and include any copyright and
 * trademark notices on all copies of the source code.  You may not
 * use, copy, merge, modify or transfer the Program except as provided
 * in this License.  Telelogic does not warrant that the Program will
 * meet your requirements or that the operation of the Program will be
 * uninterrupted and error free. You are solely responsible that the
 * selection of the Program and the modification of the source code
 * will achieve your intended results and that the results are
 * actually obtained.
 */


#ifndef __t3pl_time_h
#define __t3pl_time_h

#ifdef __cplusplus
extern "C" {
#endif

#include "t3rts.h"


/*
 * This function is presently considered to be a no-op since its provided 
 * functionality is not required for that phase
 */

void
t3pl_time_pre_initialize (int argc, char * argv [], t3rt_context_t ctx);


/*
 * Initialize the timer module
 */

void
t3pl_time_initialize (t3rt_context_t ctx);


/*
 * Finalize the timer module
 */

void
t3pl_time_finalize (t3rt_context_t ctx);


/*
 * Obtains TriTimerId corresponding to internal RTS timer handle
 * Note: return type is t3rt_binary_string_t
 */

t3rt_binary_string_t t3pl_timer_decode(t3rt_timer_handle_t handle,
                                       t3rt_alloc_strategy_t strategy,  
                                       t3rt_context_t ctx);

/*
 * Create a timer instance into the "stopped" state
 */

void
t3pl_timer_create (t3rt_timer_handle_t *handle,
                   t3rt_context_t context);


/* 
 * Delete the timer instance. It will never be used again
 */

void
t3pl_timer_delete(t3rt_timer_handle_t *handle,
                  t3rt_context_t context);


/* 
 * Start a created timer instance. Also used to restart the timer. 
 * This should set the timer into the "running" state
 */

void
t3pl_timer_start (const t3rt_timer_handle_t handle, 
                  double duration,
                  t3rt_context_t context);


/*
 * Stop a timer instance. This should set the timer into the "stopped" state
 */

void
t3pl_timer_stop (const t3rt_timer_handle_t handle,
                 t3rt_context_t context);


/*
 * Read the current value of a timer
 */

t3rt_timer_state_t
t3pl_timer_read(const t3rt_timer_handle_t handle,
                double * elapsed_time,
                t3rt_context_t context);

#ifdef __cplusplus
}
#endif

#endif

/* End of File */

