/*---------------------------------------------------------------------------
 * File Name: t3rts_activationlists.h
 *
 * Copyright 2001-2004 Telelogic AB, All rights reserved.
 * 
 * This Program is owned by Telelogic and is protected by national
 * copyright laws and international copyright treaties. Telelogic
 * grants you the right to use this Program on one computer or in one
 * local computer network at any one time.  Under this License you may
 * only modify the source code for the purpose of adapting it to your
 * environment. You must reproduce and include any copyright and
 * trademark notices on all copies of the source code.  You may not
 * use, copy, merge, modify or transfer the Program except as provided
 * in this License.  Telelogic does not warrant that the Program will
 * meet your requirements or that the operation of the Program will be
 * uninterrupted and error free. You are solely responsible that the
 * selection of the Program and the modification of the source code
 * will achieve your intended results and that the results are
 * actually obtained.
 */

#ifndef __t3rts_activationlists_h
#define __t3rts_activationlists_h

#ifdef __cplusplus
extern "C" {
#endif

#include "t3rts_common.h"
#include "t3rts_memory.h"
#include "t3rts_values_general.h"
#include "t3rts_control.h"


typedef enum t3rt_activation_list_result_internal_t {
    t3rt_activation_list_successful_proceed_c,
    t3rt_activation_list_successful_repeat_c,
    t3rt_activation_list_unsuccessful_c
} t3rt_activation_list_result_t;




/*
 * Adds test step with parameters to the end of the activation list
 * Returns default reference value for usage in 't3rt_deactivate'
 */

t3rt_value_t
t3rt_activate (const char * module_name, 
               const char * test_step_name,
               unsigned long params_count, 
               t3rt_value_t params [],
               t3rt_alloc_strategy_t strategy,
               t3rt_context_t context);



/*
 * Removes test step, corresponding to the default reference, from the activation list
 */

void
t3rt_deactivate (const t3rt_value_t default_ref,
                 t3rt_context_t context);




/*
 * Calls defaults from the activation list in the order they were added
 */

t3rt_activation_list_result_t
t3rt_activation_list_invoke (t3rt_context_t context);


#ifdef __cplusplus
}
#endif

#endif

/* End of File */

