/*---------------------------------------------------------------------------
 * File Name: t3rts_codecs.h
 *
 * Copyright 2001-2004 Telelogic AB, All rights reserved.
 *
 * This Program is owned by Telelogic and is protected by national
 * copyright laws and international copyright treaties. Telelogic
 * grants you the right to use this Program on one computer or in one
 * local computer network at any one time.  Under this License you may
 * only modify the source code for the purpose of adapting it to your
 * environment. You must reproduce and include any copyright and
 * trademark notices on all copies of the source code.  You may not
 * use, copy, merge, modify or transfer the Program except as provided
 * in this License.  Telelogic does not warrant that the Program will
 * meet your requirements or that the operation of the Program will be
 * uninterrupted and error free. You are solely responsible that the
 * selection of the Program and the modification of the source code
 * will achieve your intended results and that the results are
 * actually obtained.
 */

#ifndef __t3rts_codecs_h
#define __t3rts_codecs_h

#ifdef __cplusplus
extern "C" {
#endif

typedef enum t3rt__codecs_result_internal_t {
  t3rt_codecs_result_not_applicable_c,
  t3rt_codecs_result_failed_c,
  t3rt_codecs_result_succeeded_c
} t3rt_codecs_result_t;


typedef enum t3rt__codecs_strategy_internal_t {
  t3rt_codecs_strategy_registered_c,
  t3rt_codecs_strategy_builtin_c
} t3rt_codecs_strategy_t;



#include "t3rts_common.h"
#include "t3rts_context_decl.h"
#include "t3rts_values_general.h"
#include "t3rts_binarystrings.h"
#include "t3rts_widestrings.h"

typedef void (*t3rt_codecs_init_function_t)(t3rt_context_t ctx);

typedef void (*t3rt_codecs_setup_function_t)(t3rt_type_t type,
                                             t3rt_context_t ctx);

void
t3rt_codecs_register(t3rt_codecs_init_function_t init_function,
                     t3rt_codecs_setup_function_t setup_function,
                     t3rt_context_t ctx);


t3rt_codecs_result_t
t3rt_encode(t3rt_value_t value,
            t3rt_binary_string_t encoded_data,
            t3rt_context_t ctx);

t3rt_codecs_result_t
t3rt_decode(t3rt_binary_string_iter_t * encoded_data,
            t3rt_type_t type,
            t3rt_alloc_strategy_t strategy,
            t3rt_value_t * decoded_value,
            t3rt_context_t ctx);


t3rt_codecs_result_t
t3rt_builtin_encode(t3rt_value_t value,
                    t3rt_binary_string_t encoded_data,
                    t3rt_context_t ctx);

t3rt_codecs_result_t
t3rt_builtin_decode(t3rt_binary_string_iter_t * encoded_data,
                    t3rt_type_t type,
                    t3rt_alloc_strategy_t strategy,
                    t3rt_value_t * decoded_value,
                    t3rt_context_t ctx);


/*
 * t3rt_tci_encode() and t3rt_tci_decode() are envelops for tciEncode() and tciDecode().
 * TCI based encoders and decoders should be pluged into runtime system
 * by registering these functions using t3rt_codecs_register() 
 *
*/ 

extern t3rt_codecs_result_t
t3rt_tci_encode(t3rt_value_t value, 
                t3rt_binary_string_t encoded_data, 
                t3rt_context_t ctx);

extern t3rt_codecs_result_t
t3rt_tci_decode(t3rt_binary_string_iter_t * encoded_data,
                t3rt_type_t type,
                t3rt_alloc_strategy_t strategy,
                t3rt_value_t * decoded_value,
                t3rt_context_t ctx);

#ifdef __cplusplus
}
#endif

#endif

/* End of File */

