/*---------------------------------------------------------------------------
 * File Name: t3rts_control.h
 *
 * Copyright 2001-2004 Telelogic AB, All rights reserved.
 * 
 * This Program is owned by Telelogic and is protected by national
 * copyright laws and international copyright treaties. Telelogic
 * grants you the right to use this Program on one computer or in one
 * local computer network at any one time.  Under this License you may
 * only modify the source code for the purpose of adapting it to your
 * environment. You must reproduce and include any copyright and
 * trademark notices on all copies of the source code.  You may not
 * use, copy, merge, modify or transfer the Program except as provided
 * in this License.  Telelogic does not warrant that the Program will
 * meet your requirements or that the operation of the Program will be
 * uninterrupted and error free. You are solely responsible that the
 * selection of the Program and the modification of the source code
 * will achieve your intended results and that the results are
 * actually obtained.
 */

#ifndef __t3rts_control_h
#define __t3rts_control_h

#ifdef __cplusplus
extern "C" {
#endif



#include "t3rts_common.h"
#include "t3rts_context_decl.h"
#include "t3rts_values_general.h"


typedef enum t3rt_test_step_result_internal_t {
    t3rt_test_step_successful_proceed_c,
    t3rt_test_step_successful_repeat_c,
    t3rt_test_step_unsuccessful_c
} t3rt_test_step_result_t;



typedef void                        (* t3rt_module_register_function_t) 
                                            (t3rt_boolean_t is_root,
                                             t3rt_context_t context);

typedef void                        (* t3rt_module_initialize_function_t) 
                                            (t3rt_context_t context);

typedef void                        (* t3rt_module_params_initialize_function_t) 
                                             (t3rt_context_t context);

typedef void                        (* t3rt_module_finalize_function_t) 
                                             (t3rt_context_t context);

typedef void                        (* t3rt_function_t) 
                                            (unsigned long argc,
                                             t3rt_value_t params [],
                                             t3rt_context_t context);

typedef t3rt_test_step_result_t     (* t3rt_test_step_t) 
                                            (unsigned long argc,
                                             t3rt_value_t params [],
                                             t3rt_context_t context);

typedef void                        (* t3rt_test_case_t) 
                                            (unsigned long argc, 
                                             t3rt_value_t params [], 
                                             t3rt_context_t context);

typedef void                        (* t3rt_control_part_function_t) 
                                            (unsigned long argc, 
                                             t3rt_value_t params [], 
                                             t3rt_context_t context);

extern const t3rt_control_part_function_t   t3rt_root_control_part_c;



/*
 * Aborts execution by following proper shutdown procedures.
 */

void
t3rt_exit (void);


/* 
 * Aborts execution abruptly. 
 */

void
t3rt_abort (void);


t3rt_value_t 
t3rt_call_external_function(t3rt_type_t signature_type, 
                            t3rt_value_t params[],
                            t3rt_context_t ctx);

/*
 * The RTS entry point.
 *
 * First, the runtime engine modules are pre-initialized with 'argc' and 'argv' info. 
 * Then, the root module is registered using privided registration function. 
 * All the loaded modules are initialized (including module parameters initialization),
 * starting from the root.
 * Then, specified control part will be executed (predefined constant 
 * 't3rt_root_control_part_c' can be specified to run control part of the root module).
 * After that, cleanup is performed (using 'finalize'-functions).
 */

void
t3rt_run_test_suite (int argc,
                     char * argv [],
                     t3rt_module_register_function_t root_module_register_function,
                     t3rt_control_part_function_t control_part_function);


t3rt_boolean_t
t3rt_retrieve_module_parameter(const char * module_name,
                               const char * param_name, 
                               t3rt_value_t value, 
                               t3rt_context_t ctx);

/* function/altstep invocation */

void
t3rt_call_function (t3rt_function_t func,
		    t3rt_type_t     function_type,
		    unsigned long   argc,
		    t3rt_value_t    argv[],
		    t3rt_context_t  ctx);

t3rt_test_step_result_t
t3rt_call_altstep (t3rt_test_step_t altstep,
		   t3rt_type_t     altstep_type,
		   unsigned long   argc,
		   t3rt_value_t    argv[],
		   t3rt_context_t  ctx);

#ifdef __cplusplus
}
#endif


#endif

/* End of File */

