/*---------------------------------------------------------------------------
 * File Name: t3rts_errorhandling.h
 *
 * Copyright 2001-2004 Telelogic AB, All rights reserved.
 *
 * This Program is owned by Telelogic and is protected by national
 * copyright laws and international copyright treaties. Telelogic
 * grants you the right to use this Program on one computer or in one
 * local computer network at any one time.  Under this License you may
 * only modify the source code for the purpose of adapting it to your
 * environment. You must reproduce and include any copyright and
 * trademark notices on all copies of the source code.  You may not
 * use, copy, merge, modify or transfer the Program except as provided
 * in this License.  Telelogic does not warrant that the Program will
 * meet your requirements or that the operation of the Program will be
 * uninterrupted and error free. You are solely responsible that the
 * selection of the Program and the modification of the source code
 * will achieve your intended results and that the results are
 * actually obtained.
 */

#ifndef __t3rts_errorhandling_h
#define __t3rts_errorhandling_h

#ifdef __cplusplus
extern "C" {
#endif

#include "t3rts_common.h"
#include "t3rts_binarystrings.h"
#include "t3rts_widestrings.h"
#include "t3rts_localization.h"
#include "t3rts_context.h"

/*
 *  Error messages are located in the t3rts_errormessages.h file.
 */
#include "t3rts_errormessages.h"


typedef struct t3rt_error_description_internal_t {
            long            error_code;
            const char *    error_message;
            const char *    detailed_description;
        } t3rt_error_description_t;


void
t3rt_report_fatal_system_error (t3rt_error_description_t err, 
                                t3rt_context_t context);


void
t3rt_report_error(unsigned long line, const char* file, t3rt_wide_string_t err_msg, 
                  t3rt_context_t ctx);

/*************************************************************************
* This function performs runtime check of dereferenced pointer
* If pointer is null then provided error is posted and NULL is returned
* Otherwise passed pointer is returned 
* Function is mainly used by compiler
*************************************************************************/
void *
t3rt__assert_non_null(void *ptr,
                      unsigned long line,
                      const char* file, 
                      t3rt_wide_string_t err_msg, 
                      t3rt_context_t ctx);

#ifdef __cplusplus
}
#endif

#endif

/* End of File */

