/*---------------------------------------------------------------------------
 * File Name: t3rts_memory.h
 *
 * Copyright 2001-2004 Telelogic AB, All rights reserved.
 * 
 * This Program is owned by Telelogic and is protected by national
 * copyright laws and international copyright treaties. Telelogic
 * grants you the right to use this Program on one computer or in one
 * local computer network at any one time.  Under this License you may
 * only modify the source code for the purpose of adapting it to your
 * environment. You must reproduce and include any copyright and
 * trademark notices on all copies of the source code.  You may not
 * use, copy, merge, modify or transfer the Program except as provided
 * in this License.  Telelogic does not warrant that the Program will
 * meet your requirements or that the operation of the Program will be
 * uninterrupted and error free. You are solely responsible that the
 * selection of the Program and the modification of the source code
 * will achieve your intended results and that the results are
 * actually obtained.
 */

#ifndef __t3rts_memory_h
#define __t3rts_memory_h

#ifdef __cplusplus
extern "C" {
#endif

#include "t3rts_common.h"

typedef enum t3rt_alloc_strategy_internal_t { 
                t3rt_perm_alloc_c, 
                t3rt_temp_alloc_c, 
                t3rt_static_alloc_c,
                t3rt_temp_alloc_outer_c /* To allocate in the enclosing memory
                                           scope. Not applicable for realloc. */ 
} t3rt_alloc_strategy_t;



/*
 * Type for temporary memory scopes
 */
typedef struct t3rt_memory_scope_struct_internal_t {
  struct t3rt__memory_block_list_struct_t       *first_block; 
  struct t3rt__memory_block_list_struct_t       *last_block;  
  struct t3rt_memory_scope_struct_internal_t *outer_scope; /* Enclosing memory scope. */
} t3rt_memory_scope_t;




#include "t3rts_context_decl.h"


/*
 * Start a new temporary memory area.
 */

void
t3rt_memory_temp_begin(t3rt_memory_scope_t *memory_scope,
                       t3rt_context_t ctx);


/*
 * Abandons the temporary opened temporary memory area.
 */

void 
t3rt_memory_temp_end(t3rt_memory_scope_t *memory_scope,
                     t3rt_context_t ctx);


/*
 * Clears the current memory area.
 */

void 
t3rt_memory_temp_clear(t3rt_memory_scope_t *memory_scope,
                       t3rt_context_t ctx);


/*
 * Allocates memory according to strategy
 */

void *
t3rt_memory_temp_allocate (unsigned long size, t3rt_context_t context);



#ifdef __cplusplus
}
#endif

#endif

/* End of File */

