/*---------------------------------------------------------------------------
 * File Name: t3rts_timers.h
 *
 * Copyright 2001-2004 Telelogic AB, All rights reserved.
 *
 * This Program is owned by Telelogic and is protected by national
 * copyright laws and international copyright treaties. Telelogic
 * grants you the right to use this Program on one computer or in one
 * local computer network at any one time.  Under this License you may
 * only modify the source code for the purpose of adapting it to your
 * environment. You must reproduce and include any copyright and
 * trademark notices on all copies of the source code.  You may not
 * use, copy, merge, modify or transfer the Program except as provided
 * in this License.  Telelogic does not warrant that the Program will
 * meet your requirements or that the operation of the Program will be
 * uninterrupted and error free. You are solely responsible that the
 * selection of the Program and the modification of the source code
 * will achieve your intended results and that the results are
 * actually obtained.
 */

#ifndef __t3rts_timers_h
#define __t3rts_timers_h

#ifdef __cplusplus
extern "C" {
#endif

#include "t3rts_common.h"
#include "t3rts_values_general.h"

#include "t3pl_time.h"


/*
 * Starts timer with the indicated duration. To start timer with its default 
 * duration, pass 't3rt_duration_default_c' as duration value.
 */

void
t3rt_timer_start (t3rt_value_t timer, double duration, t3rt_context_t ctx);


/*
 * Stops timer. 'timer' may be 't3rt_value_all_c' constant
 */

void
t3rt_timer_stop (t3rt_value_t timer, t3rt_context_t ctx);


/*
 * Returns timer elapsed time
 */

double
t3rt_timer_read (t3rt_value_t timer, t3rt_context_t ctx);



/*
 * Checks if timer is running. 'timer' may be 't3rt_value_any_c' constant
 */

t3rt_boolean_t
t3rt_timer_is_running (t3rt_value_t timer, t3rt_context_t ctx);


/*
 * Checks if timer is timed out. 'timer' may be 't3rt_value_any_c' constant
 */

t3rt_boolean_t
t3rt_timer_is_timed_out (t3rt_value_t timer, t3rt_context_t ctx);


/*
 * Checks if timer has timed out within an alternative statement.
 */

t3rt_boolean_t
t3rt_timer_try_timed_out(t3rt_value_t timer, t3rt_context_t ctx);


/*
 * Informs the RTS that this timer has timed out.
 */

void
t3rt_timer_timed_out(const t3rt_timer_handle_t handle, t3rt_context_t ctx);

#ifdef __cplusplus
}
#endif

#endif

/* End of File */

