/*---------------------------------------------------------------------------
 * File Name: t3rts_xml_log.h
 *
 * Copyright 2001-2007 Telelogic AB, All rights reserved.
 * 
 * This Program is owned by Telelogic and is protected by national
 * copyright laws and international copyright treaties. Telelogic
 * grants you the right to use this Program on one computer or in one
 * local computer network at any one time.  Under this License you may
 * only modify the source code for the purpose of adapting it to your
 * environment. You must reproduce and include any copyright and
 * trademark notices on all copies of the source code.  You may not
 * use, copy, merge, modify or transfer the Program except as provided
 * in this License.  Telelogic does not warrant that the Program will
 * meet your requirements or that the operation of the Program will be
 * uninterrupted and error free. You are solely responsible that the
 * selection of the Program and the modification of the source code
 * will achieve your intended results and that the results are
 * actually obtained.
 */
 
#ifndef __t3rts_xml_logging_h
#define __t3rts_xml_logging_h

#ifdef __cplusplus
extern "C" {
#endif

/*           XML log mechanism registration              */

/*
 * t3rt_register_xml_log_mechanism
 * 
 * This function may be used to register XML log mechanism with user-provided handlers
 * for processing XML data.
 *
 * pInitFunc -     Valid pointer to a function (MUST NOT be NULL).
 *                 This function is called during XML log mechanism initialization and intended to open
 *                 necessary file descriptors, create semaphores, establish socket connections, etc
 *                 Buffer length is provided too (buffer is not NULL-terminated).
 *
 * pFinalizeFunc - Valid pointer to a function (MUST NOT be NULL).
 *                 This function is called during XML log mechanism finalization and intended to close
 *                 any opened file descriptors, destroy semaphores, etc.
 *                 Buffer length is provided too (buffer is not NULL-terminated).
 *
 * pEventFunc -    Valid pointer to a function (MUST NOT be NULL).
 *                 This function is called for every event and provides buffer with XML data describing this event,
 *                 Buffer length is provided too (buffer is not NULL-terminated).
 *                 This function MUST be thread safe.
 */

extern 
void t3rt_register_xml_log_mechanism(void (*pInitFunc)(const char *xmlLogHeader, unsigned long headerSize, t3rt_context_t ctx),
                                     void (*pEventFunc)(const char *xmlEventData, unsigned long dataSize, t3rt_context_t ctx),
                                     void (*pFinalizeFunc)(const char *xmlLogFooter, unsigned long footerSize));

#ifdef __cplusplus
}
#endif

#endif
