/*---------------------------------------------------------------------------
 * File Name: tci_cd_required.h
 *
 * Copyright 2001-2004 Telelogic AB, All rights reserved.
 * 
 * This Program is owned by Telelogic and is protected by national
 * copyright laws and international copyright treaties. Telelogic
 * grants you the right to use this Program on one computer or in one
 * local computer network at any one time.  Under this License you may
 * only modify the source code for the purpose of adapting it to your
 * environment. You must reproduce and include any copyright and
 * trademark notices on all copies of the source code.  You may not
 * use, copy, merge, modify or transfer the Program except as provided
 * in this License.  Telelogic does not warrant that the Program will
 * meet your requirements or that the operation of the Program will be
 * uninterrupted and error free. You are solely responsible that the
 * selection of the Program and the modification of the source code
 * will achieve your intended results and that the results are
 * actually obtained.
 *
 * Description:
 *      This file declares TCI CD required functions
 */
 
#ifndef __tci_cd_required_h
#define __tci_cd_required_h

#ifdef __cplusplus
extern "C" {
#endif

#include "tci_conditional.h"


                                              /* TCI-CD operations required from TE */

/* Type getTypeForName (in String typeName)
 * Returns a type representing a TTCN-3 type. 
 * Predefined TTCN-3 types can be retrieved from the TE by using the TTCN-3 keywords for the predefined types. 
 * In this case typeName denotes to the basic TTCN-3 type like "charstring", "bitstring" etc. 
 * Returns the distinct value null if the requested type can not be returned. 
 * Note that the anytype and address can not be obtained with module set to null. 
 * Although they are predefined types they might be distinct between modules. 
 * For example, address can either be the unmodified predefined type, or a user-defined type in a module. 
 * Other predefined types can not be redefined.
 *
 * typeName has to be the fully qualified type name, i.e. module.typeName
*/
TciType T3TCI(tciGetTypeForName) (IDL_ATTRIB(in) String typeName);

/* Type getInteger()	
 * Constructs and returns a basic TTCN-3 integer type.
*/
TciType T3TCI(tciGetIntegerType) ();	

/* Type getFloat()	
 * Constructs and returns a basic TTCN-3 float type.
*/
TciType T3TCI(tciGetFloatType) ();

/* Type getBoolean()	
 * Constructs and returns a basic TTCN-3 boolean type.
*/
TciType T3TCI(tciGetBooleanType) ();

/* Type getChar()	
 * Constructs and returns a basic TTCN-3 char type.
*/
TciType T3TCI(tciGetCharType) ();	

/* Type getUniversalChar()	
 * Constructs and returns a basic TTCN-3 universal char type.
*/
TciType T3TCI(tciGetUniversalCharType) ();	

/* Type getObjid()	
 * Constructs and returns a basic TTCN-3 object id type.
*/
TciType T3TCI(tciGetTciObjidType) ();

/* Type getCharstring()
 * Constructs and returns a basic TTCN-3 charstringtype.
*/
TciType T3TCI(tciGetTciCharstringType) ();
	
/* Type getUniversalCharstring()	
 * Constructs and returns a basic TTCN-3 universal charstring type.
*/
TciType T3TCI(tciGetUniversalCharstringType) ();

/* Type getHexstring()
 * Constructs and returns a basic TTCN-3 hexstring type.
*/
TciType T3TCI(tciGetHexstringType) ();
	
/* Type getBitstring()	
 * Constructs and returns a basic TTCN-3 bitstring type.
*/
TciType T3TCI(tciGetBitstringType) ();
	
/* Type getOctetstring()	
 * Constructs and returns a basic TTCN-3 octetstring type.
*/
TciType T3TCI(tciGetOctetstringType) ();
	
/* Type getVerdict()	
 * Constructs and returns a basic TTCN-3 verdict type.
*/  
TciType T3TCI(tciGetVerdictType) ();

/* void tciErrorReq(in String message)	
 * The TE will be notified about an unrecoverable error situation within the CD 
 * and forward the error indication to the test management
*/
void T3TCI(tciErrorReq) (IDL_ATTRIB(in) String message);	

#ifdef __cplusplus
}
#endif

#endif
