/*---------------------------------------------------------------------------
 * File Name: tci_misc.h
 *
 * Copyright 2001-2004 Telelogic AB, All rights reserved.
 * 
 * This Program is owned by Telelogic and is protected by national
 * copyright laws and international copyright treaties. Telelogic
 * grants you the right to use this Program on one computer or in one
 * local computer network at any one time.  Under this License you may
 * only modify the source code for the purpose of adapting it to your
 * environment. You must reproduce and include any copyright and
 * trademark notices on all copies of the source code.  You may not
 * use, copy, merge, modify or transfer the Program except as provided
 * in this License.  Telelogic does not warrant that the Program will
 * meet your requirements or that the operation of the Program will be
 * uninterrupted and error free. You are solely responsible that the
 * selection of the Program and the modification of the source code
 * will achieve your intended results and that the results are
 * actually obtained.
 *
 * Description:
 *      This file declares misceleneous C mapping specific
 *      TCI data structures 
 */
 
#ifndef __tci_misc_h
#define __tci_misc_h

#ifdef __cplusplus
extern "C" {
#endif

#include "tci_conditional.h"

typedef IDL_ATTRIB(string) char* String;

                 /* VERDICT representation */
 
/* 
 * Since the TciVerdictValue interface is defined in terms of integers, 
 * consensus must be established on which value defines which verdict. 
*/

typedef unsigned long int TciVerdictValue;

extern const long int TCI_VERDICT_NONE;
extern const long int TCI_VERDICT_PASS;
extern const long int TCI_VERDICT_INCONC;
extern const long int TCI_VERDICT_FAIL;
extern const long int TCI_VERDICT_ERROR;

#define TCI_VERDICT_NONE_STATIC    0 /* NONE */	
#define TCI_VERDICT_PASS_STATIC    1 /* PASS */		
#define TCI_VERDICT_INCONC_STATIC  2 /* INCONC */		
#define TCI_VERDICT_FAIL_STATIC    3 /* FAIL */		
#define TCI_VERDICT_ERROR_STATIC   4 /* ERROR */		

                 /* OBJID representation */

/*
 * Since the Objid value is returned "as is" via the Objid value interface, 
 * a representation must be defined.
*/

typedef struct _TciObjidElemValue
  {  
	String elem_as_ascii;  
    long int elem_as_number;  
    P_VOID aux;
  } TciObjidElemValue;	

typedef struct _TciObjidValue
  {  
    long int length;  
	IDL_ATTRIB(size_is(length))
    TciObjidElemValue *elements;
  } *TciObjidValue;	

                  /* CHARSTRING representation */
 
typedef struct _TciCharStringValue
  {  
    unsigned long int length;
	IDL_ATTRIB(size_is(length))
    char* string;
  } *TciCharStringValue;

                  /* UNIVERSAL CHARSTRING representation */
#define TCI_UC_BASE_TYPE unsigned char
#define TCI_UC_LENGTH 4

typedef TCI_UC_BASE_TYPE TciUCValue[TCI_UC_LENGTH]; 
typedef IDL_ATTRIB(size_is(TCI_UC_LENGTH)) TCI_UC_BASE_TYPE* TciUCReturnValue;

typedef struct _TciUCStringValue
  {  
    unsigned long int length;  
	IDL_ATTRIB(size_is(length))
    TciUCValue *string;
  } *TciUCStringValue;	


#ifdef __cplusplus
}
#endif
  
#endif
