/*---------------------------------------------------------------------------
 * File Name: tci_tridata.h
 *
 * Copyright 2001-2004 Telelogic AB, All rights reserved.
 * 
 * This Program is owned by Telelogic and is protected by national
 * copyright laws and international copyright treaties. Telelogic
 * grants you the right to use this Program on one computer or in one
 * local computer network at any one time.  Under this License you may
 * only modify the source code for the purpose of adapting it to your
 * environment. You must reproduce and include any copyright and
 * trademark notices on all copies of the source code.  You may not
 * use, copy, merge, modify or transfer the Program except as provided
 * in this License.  Telelogic does not warrant that the Program will
 * meet your requirements or that the operation of the Program will be
 * uninterrupted and error free. You are solely responsible that the
 * selection of the Program and the modification of the source code
 * will achieve your intended results and that the results are
 * actually obtained.
 *
 * Description:
 *      This file declares TRI data structures
 */
 
#ifndef __tci_tridata_h
#define __tci_tridata_h

#ifdef __cplusplus
extern "C" {
#endif

#include "tci_conditional.h"

/*  data is a non-null-terminated string. 
 *  bits is the number of bits used in data. bits value -1 is used to denote omitted value.
 *	The aux field is for future extensibility of TRI functionality.
 */
typedef struct _BinaryString 
  {
    IDL_ATTRIB(size_is(bits)) /* actually size = (bits%8 == 0 ? bits/8 : bits/8 + 1) */
    unsigned char *data;
    long int bits;
    P_VOID aux;
  } BinaryString;


/* 	The moduleName and objectName fields are the TTCN-3 identifiers literally.
 *  The aux field is for future extensibility of TRI functionality.
 */
typedef struct _QualifiedName 
  {
    String moduleName;
    String objectName;
    P_VOID aux;
  } QualifiedName;


typedef BinaryString TriActionTemplate;

typedef BinaryString TriAddress;

typedef struct _TriAddressList
  {
    IDL_ATTRIB(size_is(length))
    TriAddress** addrList;
    long int length;
  } TriAddressList;

typedef BinaryString TriException;
typedef QualifiedName TriFunctionId;
typedef BinaryString TriMessage;
typedef QualifiedName TriSignatureId;
typedef QualifiedName TriTestCaseId;
typedef double TriTimerDuration;
typedef BinaryString TriTimerId; /* Note: Pending ETSI statement on timer
                                     and snapshot semantics may influence
                                     future representation! */

  
typedef long int TriStatus;
#define TRI_Error -1
#define TRI_OK     0 /* All negative values are reserved for future extension of TRI functionality.*/


/*compInst is for component instance.*/
typedef struct _TriComponentId 
  {
    BinaryString  compInst;
    String        compName;
    QualifiedName compType;
  } TriComponentId;

typedef struct _TriComponentIdList
  {
    IDL_ATTRIB(size_is(length))
    TriComponentId** compIdList;
    long int length;
  } TriComponentIdList;  

typedef enum 
  {
    TRI_IN,
    TRI_INOUT,
    TRI_OUT
  } TriParameterPassingMode;

typedef struct _TriParameter
  {
    BinaryString par;
    TriParameterPassingMode mode;
  } TriParameter;

/*  No special values mark the end of parList[]. The length field shall be used
 *  to traverse this array properly.
 */
typedef struct _TriParameterList 
  {
    IDL_ATTRIB(size_is(length))
    TriParameter **parList;
    long int length;
  } TriParameterList;


/*  compInst is for component instance. For a singular (non-array) declaration,
 *  the portIndex value should be -1. The aux field is for future extensibility
 *  of TRI functionality.
 */
typedef struct _TriPortId 
  {
    TriComponentId compInst;
    String portName;
    long int portIndex;
    QualifiedName  portType;
    P_VOID aux;
  } TriPortId;


/*  No special values mark the end of portIdList[]. The length field shall be
 *  used to traverse this array properly.
 */
typedef struct _TriPortIdList 
  {
    IDL_ATTRIB(size_is(length))
    TriPortId **portIdList;
    long int length;
  } TriPortIdList;

#ifdef __cplusplus
}
#endif

#endif

