/*---------------------------------------------------------------------------
 * File Name: tci_types.h
 *
 * Copyright 2001-2004 Telelogic AB, All rights reserved.
 * 
 * This Program is owned by Telelogic and is protected by national
 * copyright laws and international copyright treaties. Telelogic
 * grants you the right to use this Program on one computer or in one
 * local computer network at any one time.  Under this License you may
 * only modify the source code for the purpose of adapting it to your
 * environment. You must reproduce and include any copyright and
 * trademark notices on all copies of the source code.  You may not
 * use, copy, merge, modify or transfer the Program except as provided
 * in this License.  Telelogic does not warrant that the Program will
 * meet your requirements or that the operation of the Program will be
 * uninterrupted and error free. You are solely responsible that the
 * selection of the Program and the modification of the source code
 * will achieve your intended results and that the results are
 * actually obtained.
 *
 * Description:
 *      This file declares TCI functions used to process types
 */
 
#ifndef __tci_types_h
#define __tci_types_h

#ifdef __cplusplus
extern "C" {
#endif

#include "tci_conditional.h"

/***************************************************************
*   Generic TCI Type operations
*   Six operations defined in standard
***************************************************************/

/*
 * TciModuleIdType getDefiningModule() 	
 * Returns the module identifier of the module in which type is defined. 
 * Returns the distinct value null if type is a TTCN-3 base type, e.g. boolean, integer, etc.)
*/
TciModuleIdType T3TCI(tciGetDefiningModule) (IDL_ATTRIB(in) TciType inst);

/*
 * TString getName()	
 * Returns the name of the type as defined in the TTCN-3 module
*/
String T3TCI(tciGetName) (IDL_ATTRIB(in) TciType inst);

/*
 * TciTypeClassType getTypeClass()	
 * Returns the type class of the respective type. 
 * A value of TciTypeClassType can have one of the following constants: 
 * ADDRESS, ANYTYPE, BITSTRING, BOOLEAN, CHAR, CHARSTRING, COMPONENT, 
 * DEFAULT, PORT, TIMER, TEMPLATE (formal template parameter),
 * ENUMERATED, FLOAT, HEXSTRING, INTEGER, OBJID, OCTETSTRING, RECORD, 
 * RECORD_OF, SET, SET_OF, UNION, UNIVERSAL_CHARSTRING, UNIVERSAL_CHAR, VERDICT
*/
TciTypeClassType T3TCI(tciGetTypeClass) (IDL_ATTRIB(in) TciType inst);

/* 
 * Value newInstance()	
 * Returns a freshly created value of the given type. 
 * This initial value of the created value is undefined
*/
TciValue T3TCI(tciNewInstance) (IDL_ATTRIB(in) TciType inst);

/* 
 * TString getTypeEncoding()
 * Returns the type encoding attribute as defined in the TTCN-3 module
*/
String T3TCI(tciGetTypeEncoding) (IDL_ATTRIB(in) TciType inst);

/*
 * TString getTypeEncodingVariant()	
 * This operation returns the value encoding variant attribute as defined in TTCN-3, if any. 
 * If no encoding variant attribute is defined the distinct value null is returned
*/
String T3TCI(tciGetTypeEncodingVariant) (IDL_ATTRIB(in) TciType inst);

/*
 * TString* getTypeExtension()	
 * This operation returns the extension attribute as defined in TTCN-3, if any. 
 * If no extension attribute is defined the distinct value null is returned
*/


IDL_ATTRIB(local)
String* T3TCI(tciGetTypeExtension) (IDL_ATTRIB(in) TciType inst);

#ifdef __cplusplus
}
#endif

#endif
