/*---------------------------------------------------------------------------
 * File Name: example_triutil.h
 *
 * Copyright 2001-2004 Telelogic AB, All rights reserved.
 * 
 * This Program is owned by Telelogic and is protected by national
 * copyright laws and international copyright treaties. Telelogic
 * grants you the right to use this Program on one computer or in one
 * local computer network at any one time.  Under this License you may
 * only modify the source code for the purpose of adapting it to your
 * environment. You must reproduce and include any copyright and
 * trademark notices on all copies of the source code.  You may not
 * use, copy, merge, modify or transfer the Program except as provided
 * in this License.  Telelogic does not warrant that the Program will
 * meet your requirements or that the operation of the Program will be
 * uninterrupted and error free. You are solely responsible that the
 * selection of the Program and the modification of the source code
 * will achieve your intended results and that the results are
 * actually obtained.
 *
 * Description:
 *     TRI utility functions
 */


#ifndef __example_triutil_h
#define __example_triutil_h

#ifdef __cplusplus
extern "C" {
#endif

#include "t3tri.h"
#include "t3rts.h"


t3rt_boolean_t
t3tri_componentId_is_equal(const TriComponentId *comp1,
                           const TriComponentId *comp2);

t3rt_boolean_t
t3tri_BinaryString_is_equal(const BinaryString *str1,
                            const BinaryString *str2);

/*
 * This function is only supposed to be called from within
 * the triPAReset, triSAReset or triExecuteTestcase functions.
 */
t3rt_context_t
t3tri_get_context();

void
clear_BinaryString(BinaryString *str,
                   t3rt_alloc_strategy_t strategy,
                   t3rt_context_t context);


/*
 * TRI constructors.
 */

QualifiedName *
tri__create_QualifiedName(const char* moduleName, const char* objectName,
                          void* aux, t3rt_alloc_strategy_t strategy,
                          QualifiedName *name, t3rt_context_t ctx);


void
tri__create_TriParameterList(long param_count,
                             t3rt_alloc_strategy_t strategy,
                             TriParameterList *parlist,
                             t3rt_context_t ctx);

void
tri__create_TriParameter(t3rt_binary_string_t enc_par,
                         t3rt_field_properties_t props,
                         t3rt_alloc_strategy_t strategy,
                         TriParameter *par,
                         t3rt_context_t ctx);



/*
 * TRI to T3 RTS conversions.
 */

BinaryString *
tri__t3_to_tri_BinaryString(t3rt_binary_string_t t3string,
                            t3rt_alloc_strategy_t strategy,
                            BinaryString *bstring,
                            t3rt_context_t ctx);


/*
 * T3 RTS to TRI conversions
 */

t3rt_binary_string_t
tri__tri_to_t3_binary_string(const BinaryString *tri_str,
                             t3rt_alloc_strategy_t strategy,
                             t3rt_context_t ctx);

#ifdef __cplusplus
}
#endif
                             
#endif

/* End of File */

