/*---------------------------------------------------------------------------
 * File Name: t3rts_conditional.c
 *
 * Copyright 2001-2004 Telelogic AB, All rights reserved.
 *
 * This Program is owned by Telelogic and is protected by national
 * copyright laws and international copyright treaties. Telelogic
 * grants you the right to use this Program on one computer or in one
 * local computer network at any one time.  Under this License you may
 * only modify the source code for the purpose of adapting it to your
 * environment. You must reproduce and include any copyright and
 * trademark notices on all copies of the source code.  You may not
 * use, copy, merge, modify or transfer the Program except as provided
 * in this License.  Telelogic does not warrant that the Program will
 * meet your requirements or that the operation of the Program will be
 * uninterrupted and error free. You are solely responsible that the
 * selection of the Program and the modification of the source code
 * will achieve your intended results and that the results are
 * actually obtained.
 */

#include "t3rts_conditional.h"

#ifndef T3RT_NO_BUILTIN_LOG
#include "t3rts_builtin_log.h"
#include "t3rts_customizable_log.h"
#endif

#ifdef T3RT_MSC96_EVENT_LOG
#include <stdlib.h>
#include "t3rts_msc96_event_log.h"
#endif

#ifdef T3RT_DEBUG
#include "t3rts_debugger.h"
#endif

#ifdef T3RT_XML_EVENT_LOG
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <errno.h>
#include "t3rts_xml_log.h"

/* XML log event handlers */
static void xmlLogInit(const char *xmlLogHeader, unsigned long headerSize, t3rt_context_t ctx);
static void xmlLogEvent(const char *xmlEventData, unsigned long dataSize, t3rt_context_t ctx);
static void xmlLogFinalize(const char *xmlLogFooter, unsigned long footerSize);
static const char * checkXmlLogRedirection (int argc, char * argv []);

/* XML log global data */
static const char * gpXmlLogOutname = NULL;
static FILE * gpXmlLogOutfile = NULL;
#endif

void
t3rt_register_default_logging (int argc, char * argv [])
{
#ifndef T3RT_NO_BUILTIN_LOG

#ifndef T3RT_LEGACY_BUILTIN_LOG
    t3rt_register_customizable_log_mechanism (argc, argv);
#else    
    t3rt_register_builtin_log_mechanism (argc, argv);
#endif
    
#endif
}


void
t3rt_register_provided_logging (int argc, char * argv [])
{
#ifdef T3RT_MSC96_EVENT_LOG
    if (getenv("T3RT_NO_MSC96_EVENT_LOG") == NULL) {
        t3rt_register_msc96_log_mechanism ();
    }
#endif
#ifdef T3RT_XML_EVENT_LOG
    if (getenv("T3RT_NO_XML_EVENT_LOG") == NULL) {
        gpXmlLogOutname = checkXmlLogRedirection(argc, argv);
        t3rt_register_xml_log_mechanism(&xmlLogInit, &xmlLogEvent, &xmlLogFinalize);
    }
#endif
#ifdef T3RT_DEBUG
    /* This only registers TTCN-3 debugger.
     * To start debugger certain RTConf paramter should be set.
    */
    t3rt_register_debugger(argc, argv);
#endif
}

#ifdef T3RT_XML_EVENT_LOG
/**********************************************************************
 *              XML log registration and handlers
 *
 *********************************************************************/

/*
 * checkXmlLogRedirection 
 */

static const char *
checkXmlLogRedirection (int argc, char * argv [])
{  
  int i;

  for (i = 0; i < argc; ++i) {
    if (strcmp("-t3rtxmlout", argv[i]) == 0) {
      if (i < (argc - 1))
        return argv[i+1];
    }
  }

  return "ExecutionLog.xml";
}

/*
 * xmlLogInit
 */

static void 
xmlLogInit(const char *xmlLogHeader, unsigned long headerSize, t3rt_context_t ctx)
{
  if ((gpXmlLogOutfile = fopen(gpXmlLogOutname, "w")) == NULL) {
    fprintf(stderr, "Failed opening '%s' file: '%s'", gpXmlLogOutname, strerror(errno));
    exit(1);
  }
  fwrite(xmlLogHeader, 1, headerSize, gpXmlLogOutfile);
}

/*
 * xmlLogEvent
 */

static void 
xmlLogEvent(const char *xmlEventData, unsigned long dataSize, t3rt_context_t ctx)
{
  fwrite(xmlEventData, 1, dataSize, gpXmlLogOutfile);
}

/*
 * xmlLogFinalize
 */

static void 
xmlLogFinalize(const char *xmlLogFooter, unsigned long footerSize)
{
  fwrite(xmlLogFooter, 1, footerSize, gpXmlLogOutfile);
  fclose(gpXmlLogOutfile);
}

#endif


/* End of File */

